import { request, getRequestParameter } from '@/utils/request';
import { getSessionID } from '@/utils/auth';
import store from '@/store';
import qs from 'qs';

/**
 * @description 得到语言列表
 */
export function GetLanguageList() {
  let params = getRequestParameter('language_manager-GetLanguageList');

  return request({
    method: 'post',
    url: process.env.VUE_APP_FILE_SERVE,
    params
  });
}

/**
 * @description 获取词汇包
 * @param { object } language_type 语言类型 word_key_list 词汇键值列表
 */
export function GetWordPack(Parameter) {
  let data = {
    MethodName: 'language_manager-GetWordPack',
    Parameter: JSON.stringify(Parameter)
  };
  return request({
    method: 'post',
    url: process.env.VUE_APP_FILE_SERVE,
    data,
    transformRequest: [
      function (data) {
        return qs.stringify(data);
      }
    ],
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
    }
  });
}

/**
 * @description 上传文件
 * @param {String} SecurityLevel 保密级别
 * @returns
 */
export function fileUpload(SecurityLevel, formData) {
  let params = {
    UserCode: store.state.user.user_code,
    UserType: store.state.user.user_type,
    SessionID: getSessionID(),
    SecurityLevel
  };

  return request({
    method: 'post',
    url: 'GCLSFileServer/WebFileUpload',
    params,
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data: {
      formData
    }
  });
}
