import { getSessionID, removeSessionID, setSessionID } from '@/utils/auth';
import { user } from '@/store/mutation-types';
import { resetRouter } from '@/router';
import { login, updateLanguageType } from '@/api/user';

const getDefaultSate = () => {
  return {
    session_id: getSessionID(),
    user_code: '',
    user_real_name: '',
    user_type: '',
    language_type: localStorage.getItem('language_type') || 'ZH'
  };
};

const state = getDefaultSate();

const mutations = {
  [user.RESET_STATE]: state => {
    Object.assign(state, getDefaultSate());
  },
  [user.SET_SESSION_ID]: (state, session_id) => {
    state.session_id = session_id;
  },
  [user.SET_USER_INFO]: (state, { user_code, user_real_name, user_type, language_type }) => {
    state.user_code = user_code;
    state.user_real_name = user_real_name;
    state.user_type = user_type;
    state.language_type = language_type;
  },
  [user.UPDATE_LANGUAGE_TYPE]: (state, language_type) => {
    localStorage.setItem('language_type', language_type);
    state.language_type = language_type;
  }
};

const actions = {
  // 登录
  login({ commit }, userInfo) {
    const { loginForm } = userInfo;
    return new Promise((reslove, reject) => {
      login(loginForm)
        .then(response => {
          let { session_id } = response;
          setSessionID(session_id);
          commit(user.SET_USER_INFO, response);
          commit(user.SET_SESSION_ID, session_id);
          reslove();
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  // 用户退出
  signOut({ commit }) {
    return new Promise(resolve => {
      removeSessionID();
      resetRouter();
      commit(user.RESET_STATE);
      resolve();
    });
  },

  // 用户更换语言类型
  updateLanguageType({ commit }, language_type) {
    return new Promise((reslove, reject) => {
      updateLanguageType({ language_type })
        .then(() => {
          commit(user.UPDATE_LANGUAGE_TYPE, language_type);
          reslove();
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  resetSessionID({ commit }) {
    return new Promise(reslove => {
      removeSessionID();
      commit(user.RESET_STATE);
      reslove();
    });
  }
};

export default {
  namespaced: true,
  state,
  mutations,
  actions
};
